@@ -273,7 +273,7 @@ class AndroidResourceUnit(base.TranslationUnit):
             if cloned_target.text is not None:
                 cloned_target.text = self.unescape(cloned_target.text, False)
             for xmlelement in cloned_target.iterdescendants():
-                if xmlelement.text is not None:
+                if xmlelement.text is not None and xmlelement.tag is not etree.Entity:
                     xmlelement.text = self.unescape(xmlelement.text, False)
                 if xmlelement.tail is not None:
                     xmlelement.tail = self.unescape(xmlelement.tail, False)
@@ -292,11 +292,22 @@ class AndroidResourceUnit(base.TranslationUnit):
             return target
 
     def set_xml_text_value(self, target, xmltarget):
-        if '<' in target:
+        if '<' in target or '&' in target:
+            # Try to handle it as legacy XML
+            parser = etree.XMLParser(strip_cdata=False, resolve_entities=False)
+            if self._store is not None:
+                cloned_doc = copy.deepcopy(self._store.document)
+                cloned_root = cloned_doc.getroot()
+                for child in cloned_root.xpath('*'):
+                    cloned_root.remove(child)
+                template = etree.tostring(cloned_doc, encoding='unicode')
+            else:
+                template = '<resources></resources>'
             try:
-                # Try to handle it as legacy XML
-                parser = etree.XMLParser(strip_cdata=False, resolve_entities=False)
-                newstring = etree.fromstring('<string>%s</string>' % target, parser)
+                newstring = etree.fromstring(
+                    template.replace('</resources>', '<string>%s</string></resources>' % target),
+                    parser
+                )[0]
             except Exception:
                 # Fallback to string with XML escaping
                 xmltarget.text = self.escape(target)
@@ -305,7 +316,7 @@ class AndroidResourceUnit(base.TranslationUnit):
                 if newstring.text is not None:
                     newstring.text = self.escape(newstring.text, False)
                 for x in newstring.iterdescendants():
-                    if x.text is not None:
+                    if x.text is not None and x.tag is not etree.Entity:
                         x.text = self.escape(x.text, False)
                     if x.tail is not None:
                         x.tail = self.escape(x.tail, False)
@@ -328,7 +339,7 @@ class AndroidResourceUnit(base.TranslationUnit):
         if self.xmlelement.tag != "plurals":
             return self.get_xml_text_value(self.xmlelement)
         return multistring([data.forceunicode(self.get_xml_text_value(entry))
-                            for entry in self.xmlelement.iterchildren()])
+                            for entry in self.xmlelement.iterchildren('item')])
 
     @target.setter
     def target(self, target):
@@ -443,6 +454,7 @@ class AndroidResourceFile(lisa.LISAfile):
     bodyNode = "resources"
     XMLskeleton = '''<?xml version="1.0" encoding="utf-8"?>
 <resources></resources>'''
+    _doctype = None
 
     def initbody(self):
         """Initialises self.body so it never needs to be retrieved from the XML
@@ -454,9 +466,9 @@ class AndroidResourceFile(lisa.LISAfile):
     def serialize(self, out=None):
         """Converts to a string containing the file's XML"""
         out.write(b'<?xml version="1.0" encoding="utf-8"?>\n')
-        reindent(self.document.getroot(), indent="    ", max_level=3)
+        reindent(self.document.getroot(), indent="    ", leaves=('string', 'item'))
         self.document.write(out, pretty_print=False, xml_declaration=False,
-                            encoding='utf-8')
+                            encoding='utf-8', doctype=self._doctype)
 
     def parse(self, xml):
         """Populates this object from the given xml string"""
@@ -505,12 +517,28 @@ class AndroidResourceFile(lisa.LISAfile):
         newns = {}
         do_cleanup = False
         if new:
+            # Include any possible new namespaces
             newns = self.body.nsmap
             for ns in unit.xmlelement.nsmap:
                 if ns not in newns:
                     do_cleanup = True
                     newns[ns] = unit.xmlelement.nsmap[ns]
 
+            # Detect if unit is using XML entities
+            hasentity = False
+            for xmlelement in unit.xmlelement.iterdescendants():
+                if xmlelement.tag is etree.Entity:
+                    hasentity = True
+                    break
+
+            # Copy doctype to include possibly new entities
+            if hasentity:
+                cloned_doc = copy.deepcopy(unit._store.document)
+                cloned_doc.getroot().clear()
+                self._doctype = etree.tostring(
+                    cloned_doc, xml_declaration=False, encoding='unicode'
+                ).rsplit('\n', 1)[0]
+
         super(AndroidResourceFile, self).addunit(unit, new)
         # Move aliased namespaces to the <resources> tag
         # The top_nsmap was introduced in LXML 3.5.0
