@@ -26,6 +26,7 @@ import six
 from six.moves import html_parser
 from six.moves.html_entities import name2codepoint
 
+from translate.misc.deprecation import deprecated
 from translate.storage import base
 from translate.storage.base import ParseError
 
@@ -100,16 +101,22 @@ class htmlunit(base.TranslationUnit):
         self.locations = []
         self.source = source
 
-    def getsource(self):
+    @property
+    def source(self):
         #TODO: Rethink how clever we should try to be with html entities.
         text = self._text.replace("&amp;", "&")
         text = text.replace("\r\n", " ").replace("\n", " ").replace("\r", " ")
         return text
 
-    def setsource(self, source):
+    @source.setter
+    def source(self, source):
         self._rich_source = None
         self._text = safe_escape(source)
-    source = property(getsource, setsource)
+
+    # Deprecated on 2.3.1
+    @deprecated("Use `source` property instead")
+    def getsource(self):
+        return self.source
 
     def addlocation(self, location):
         self.locations.append(location)
