@@ -81,7 +81,7 @@ from translate.storage import base
 class JsonUnit(base.TranslationUnit):
     """A JSON entry"""
 
-    def __init__(self, source=None, item=None, notes=None, **kwargs):
+    def __init__(self, source=None, item=None, notes=None, placeholders=None, **kwargs):
         identifier = str(uuid.uuid4())
         # Global identifier across file
         self._id = '.' + identifier
@@ -91,6 +91,7 @@ class JsonUnit(base.TranslationUnit):
         self._type = six.text_type if source is None else type(source)
         if notes:
             self.notes = notes
+        self.placeholders = placeholders
         if source:
             if issubclass(self._type, six.string_types):
                 self.target = source
@@ -160,8 +161,13 @@ class JsonFile(base.TranslationStore):
     def serialize(self, out):
         def merge(d1, d2):
             for k in d2:
-                if k in d1 and isinstance(d1[k], dict) and isinstance(d2[k], dict):
-                    merge(d1[k], d2[k])
+                if k in d1:
+                    if isinstance(d1[k], dict) and isinstance(d2[k], dict):
+                        merge(d1[k], d2[k])
+                    elif isinstance(d1[k], list) and isinstance(d2[k], list):
+                        d1[k].extend(d2[k])
+                    else:
+                        d1[k] = d2[k]
                 else:
                     d1[k] = d2[k]
         units = OrderedDict()
@@ -170,8 +176,7 @@ class JsonFile(base.TranslationStore):
         out.write(json.dumps(units, **self.dump_args).encode(self.encoding))
         out.write(b'\n')
 
-    def _extract_translatables(self, data, stop=None, prev="", name_node=None,
-                               name_last_node=None, last_node=None):
+    def _extract_units(self, data, stop=None, prev="", name_node=None, name_last_node=None, last_node=None):
         """Recursive function to extract items from the data files
 
         :param data: the current branch to walk down
@@ -183,22 +188,20 @@ class JsonFile(base.TranslationStore):
         """
         if isinstance(data, dict):
             for k, v in six.iteritems(data):
-                for x in self._extract_translatables(v, stop,
-                                                     "%s.%s" % (prev, k),
-                                                     k, None, data):
+                for x in self._extract_units(v, stop, "%s.%s" % (prev, k), k, None, data):
                     yield x
         elif isinstance(data, list):
             for i, item in enumerate(data):
-                for x in self._extract_translatables(item, stop,
-                                                     "%s[%s]" % (prev, i),
-                                                     i, name_node, data):
+                for x in self._extract_units(item, stop, "%s[%s]" % (prev, i), i, name_node, data):
                     yield x
         # apply filter
         elif (stop is None or
               (isinstance(last_node, dict) and name_node in stop) or
               (isinstance(last_node, list) and name_last_node in stop)):
 
-            yield (prev, data, name_node, '')
+            unit = self.UnitClass(data, name_node)
+            unit.setid(prev)
+            yield unit
 
     def parse(self, input):
         """parse the given file or file source string"""
@@ -215,12 +218,9 @@ class JsonFile(base.TranslationStore):
         try:
             self._file = json.loads(input, object_pairs_hook=OrderedDict)
         except ValueError as e:
-            raise base.ParseError(e.message)
+            raise base.ParseError(e)
 
-        for k, data, item, notes in self._extract_translatables(self._file,
-                                                                stop=self._filter):
-            unit = self.UnitClass(data, item, notes)
-            unit.setid(k)
+        for unit in self._extract_units(self._file, stop=self._filter):
             self.addunit(unit)
 
 
@@ -232,6 +232,9 @@ class JsonNestedUnit(JsonUnit):
     def getvalue(self):
         ret = self.converttarget()
         for k in reversed(self.getkey()):
+            if '[' in k and k[-1] == ']':
+                k = k.split('[')[0]
+                ret = [ret]
             ret = OrderedDict({k: ret})
         return ret
 
@@ -249,6 +252,8 @@ class WebExtensionJsonUnit(JsonUnit):
         ))
         if self.notes:
             value['description'] = self.notes
+        if self.placeholders:
+            value['placeholders'] = self.placeholders
         return {self.getid(): value}
 
 
@@ -263,10 +268,16 @@ class WebExtensionJsonFile(JsonFile):
 
     UnitClass = WebExtensionJsonUnit
 
-    def _extract_translatables(self, data, stop=None, prev="", name_node=None,
-                               name_last_node=None, last_node=None):
+    def _extract_units(self, data, stop=None, prev="", name_node=None, name_last_node=None, last_node=None):
         for item, value in six.iteritems(data):
-            yield (item, value.get('message', ''), item, value.get('description', ''))
+            unit = self.UnitClass(
+                value.get('message', ''),
+                item,
+                value.get('description', ''),
+                value.get('placeholders', None)
+            )
+            unit.setid(item)
+            yield unit
 
 
 class I18NextUnit(JsonNestedUnit):
@@ -329,8 +340,7 @@ class I18NextFile(JsonNestedFile):
 
     UnitClass = I18NextUnit
 
-    def _extract_translatables(self, data, stop=None, prev="", name_node=None,
-                               name_last_node=None, last_node=None):
+    def _extract_units(self, data, stop=None, prev="", name_node=None, name_last_node=None, last_node=None):
         if isinstance(data, dict):
             plurals_multiple = [key.rsplit('_', 1)[0] for key in data if key.endswith('_0')]
             plurals_simple = [key.rsplit('_', 1)[0] for key in data if key.endswith('_plural')]
@@ -363,15 +373,15 @@ class I18NextFile(JsonNestedFile):
                         processed.add(key)
                         sources.append(data[key])
                         items.append(key)
-                    yield ("%s.%s" % (prev, plural_base), multistring(sources), items, '')
+                    unit = self.UnitClass(multistring(sources), items)
+                    unit.setid("%s.%s" % (prev, plural_base))
+                    yield unit
                     continue
 
-                for x in self._extract_translatables(v, stop,
-                                                     "%s.%s" % (prev, k),
-                                                     k, None, data):
+                for x in self._extract_units(v, stop, "%s.%s" % (prev, k), k, None, data):
                     yield x
         else:
-            parent = super(I18NextFile, self)._extract_translatables(
+            parent = super(I18NextFile, self)._extract_units(
                 data, stop, prev, name_node, name_last_node, last_node
             )
             for x in parent:
