@@ -1,5 +1,5 @@
-#!/usr/bin/env python2
 # -*- coding: utf-8 -*-
+from __future__ import print_function
 
 from translate.storage import catkeys, test_base
 
